/********************************************************/
/*	SAMPLE PROGRAM 2 FOR MSA0654-MEAUST BOARD	*/
/*	FILENAME: sample2.c				*/
/*	WRITTEN BY: Alan Suyko  28/7/99			*/
/*	DESCRIPTION:  					*/
/*	-- Uses port P0 and P1 and Timer A0 to display 	*/
/*	count up sequence on LED2 at 1 sec update 	*/
/*	interval.					*/
/*							*/
/*	Copyright 1999 by MITSUBISHI ELECTRIC AUSTRALIA	*/
/*	All rights reserved. See Terms and Conditions	*/
/*	document regarding the use of this sample	*/
/*	program.					*/
/********************************************************/ 	

#include "sfr62.h"
#include "leddata.h"
void main(void);
void initport(void);
void initTimerA0(void);
void startTimerA0(void);
void setTimerA0int(void);
void TimerA0int(void);

#pragma INTERRUPT TimerA0int


void main(void)
{
	initport();
	initTimerA0();
	setTimerA0int();
	startTimerA0();
	while(1);	// endless loop
}

void initport(void)
{
	pd0 = 0xFF;	// output mode 
	pd1 = 0xFF;	// output mode 
	pu00 = 0;	// no pull up for P0_0 to P0_3 
	pu01 = 0;	// no pull up for P0_4 to P0_7 
	pu02 = 0;	// no pull up for P1_0 to P1_3 
	p1 = 0xFD;	// enable LED2 and disable LED1
	p0 = 0xFF;	// turn off all segments
}


void initTimerA0(void)
{
    	ta0mr = 0x80;       // XX0X XX00 
                            // |||| |||+- must always be 0 in timer mode
                            // |||| ||+-- must always be 0 in timer mode
                            // |||| |+--- 0: pulse is not output at pin TA0out
                            // |||| |     1: pulse is output at pin TA0out
                            // |||| |        TA0out is automatically  output
                            // |||| +---- 0: gate function: timer counts only 
                            // ||||          when TA0in is held "L"
                            // ||||       1: gate function: timer counts only
                            // ||||          when TA0in is held "H"
                            // |||+------ 0: gate function not available
                            // |||        1: gate function available
                            // ||+------- must always be 0 in timer mode
                            // |+-------- count source select bits:
                            // +--------- count source select bits:
                            //            00:  f1
                            //            01:  f8
                            //            10:  f32
                            //            11:  fc32

    	ta0 = 0xC350;	    // Set up Timer A0 Reload Register for 0.1 sec interval interrupt
}

void startTimerA0(void)
{
    tabsr |= 0x01;          //	1: start timer A0 (count flag)
}


void setTimerA0int(void)
{
    ta0ic = 0x01;           // ---- XXXX
                            //      ||||
                            //      |||+-- Interupt priority level select bit
                            //      ||+--- Interupt priority level select bit
                            //      |+---- Interupt priority level select bit
                            //      |      000: Level 0 (interrupt disabled)
                            //      |      001: Level 1
                            //      |      010: Level 2
                            //      |      011: Level 3
                            //      |      100: Level 4
                            //      |      101: Level 5
                            //      |      110: Level 6
                            //      |      111: Level 7
                            //      +----- Interupt request bit 
                            //             0: Interrupt not requested
                            //             1: Interrupt requested
}


void TimerA0int(void)		// interrupt function
{	
	static unsigned char one_hundred_msec_count = 0;
	static unsigned char digit = 0;

	asm("fset I");		// enable interrupts

	one_hundred_msec_count++;
	if (one_hundred_msec_count == 10)	// 1 sec has elapsed if true
		{
		one_hundred_msec_count = 0;
		digit++;
		if (digit == 10)
			digit = 0;
		p0 = leddigit[digit];	// display digits '0' - '9' in LED2
		}
}


